@@ -1,5 +1,5 @@
 /* server.c --- DIGEST-MD5 mechanism from RFC 2831, server side.
- * Copyright (C) 2002, 2003, 2004  Simon Josefsson
+ * Copyright (C) 2002, 2003, 2004, 2006, 2007  Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Lesser General Public
  * License along with GNU SASL Library; if not, write to the Free
- * Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
- * 02111-1307 USA
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  *
  */
 
@@ -153,7 +153,7 @@ _gsasl_digest_md5_server_step (Gsasl_session * sctx,
       gsasl_property_set (sctx, GSASL_AUTHZID, state->response.authzid);
       gsasl_property_set (sctx, GSASL_REALM, state->response.realm);
 
-      /* FIXME: qop, cipher, maxbuf. */
+      /* FIXME: qop, cipher, maxbuf.  Charset convert username. */
 
       /* Compute secret.  TODO: Add callback to retrieve hashed
          secret. */
@@ -234,6 +234,9 @@ _gsasl_digest_md5_server_finish (Gsasl_session * sctx, void *mech_data)
 {
   _Gsasl_digest_md5_server_state *state = mech_data;
 
+  if (!state)
+    return;
+
   digest_md5_free_challenge (&state->challenge);
   digest_md5_free_response (&state->response);
   digest_md5_free_finish (&state->finish);
